@@ -16,12 +16,10 @@
 
 #' @title clean_path_name helper function
 #'
-#' @description Function to clean paths to surely have a tailing slash or not
+#' @description Function to clean paths to surely have a tailing slash or not.
+#'
+#' @inheritParams DIZtools::clean_path_name
 #'
-#' @param pathname A character string. A path name to be cleaned
-#'   (to have a tailing slash or not).
-#' @param remove.slash (boolean) Default: FALSE. Should the result
-#'   contain the tailing slash or remove it?
 #' @return The result is the input but with an tailing slash.
 #'
 #'
@@ -33,9 +31,10 @@
 #' @export
 #'
 clean_path_name <- function(pathname, remove.slash = FALSE) {
-  if (remove.slash) {
-    return(gsub("\\/$", "", pathname))
-  } else {
-    return(gsub("([[:alnum:]])$", "\\1/", pathname))
-  }
+  # function is required by DQAstats
+  DIZtools::clean_path_name(
+    pathname = pathname,
+    remove.slash = remove.slash
+  ) %>%
+    return()
 }
