@@ -19,10 +19,8 @@
 #' @description Function to clean the local environment.
 #'   The call of this function clears the console and the local environment
 #'   variables.
-#' @param keep_environment (Optional, boolean) If true, the objects from the
-#'   environment will not be deleted/emptied.
-#' @param keep_console (Optional, boolean) If true, the console will not
-#'   be emptied.
+#'
+#' @inheritParams DIZtools::clear
 #'
 #' @return Nothing.
 #'
@@ -30,20 +28,9 @@
 #'
 clear <- function(keep_environment = FALSE,
                   keep_console = FALSE) {
-  ## Inspiration: https://stackoverflow.com/questions/62901476
-  gctorture(TRUE)
-  if (!keep_console) {
-    ## Cleanup the backend in RStudio:
-    ## Clears the console (imitates CTR + L)
-    cat("\014")
-  }
-  if (!keep_environment) {
-    # Clears the Global Environment/variables/data:
-    rm(list = ls(all.names = TRUE, envir = sys.frame(-1)),
-       envir = sys.frame(-1))
-  }
-  ## Garbage collector/Clear unused RAM:
-  invisible(gc())
-  ## Turn it off (important or it gets very slow):
-  gctorture(FALSE)
+  .Deprecated("DIZtools::clear")
+  DIZtools::clear(
+    keep_environment = keep_environment,
+    keep_console = keep_console
+  )
 }
