@@ -17,7 +17,8 @@
 #' @title Converts the first letter of the input string to uppercase
 #' @description Converts the first letter of the input string to uppercase
 #'
-#' @param x A character string. E.g. "hello world" will become "Hello world".
+#' @inheritParams DIZtools::firstup
+#'
 #' @return Returns the input string but with a capital first letter.
 #' @examples
 #' firstup("first letter of this string will be upper case as return")
@@ -25,6 +26,7 @@
 #' @export
 #'
 firstup <- function(x) {
-  substr(x, 1, 1) <- toupper(substr(x, 1, 1))
-  return(x)
+  # function is required by DQAgui
+  DIZtools::firstup(x = x) %>%
+    return()
 }
