@@ -18,8 +18,8 @@
 #'
 #' @description Function to return elements of x that are not in y.
 #'
-#' @param x Object 1.
-#' @param y Object 2.
+#' @inheritParams DIZtools::`%notin%`
+#'
 #' @return Returns the result of !%in%(x,y)
 #' @examples
 #' tmp1 <- c("a","b","c")
@@ -29,13 +29,9 @@
 # define %notin% function
 # nolint start
 "%notin%" <- function(x, y) {
-  # workaround until DIZutils is on CRAN
-  # (when using 'importFrom DIZutils %notin%', error exists due to
-  # referencing package in NAMESPACE but not as Import in DESCRIPTION)
-  # "%notin%" <- utils::getFromNamespace(
-  #   x = "%notin%",
-  #   ns = "DIZutils"
-  # )
-  return(!("%in%"(x, y)))
+  # do not deprecate this function as it is extensively used in
+  # downstream package DQAstats
+  DIZtools::`%notin%`(x = x, y = y) %>%
+    return()
 }
 # nolint end
